# Fork of Python STEEM Library

`steem-python` is the official STEEM library for Python. It comes with a BIP38 encrypted wallet and a practical CLI utility called `steempy`. Due to inactivity in the official repo, I will maintain a seperate fork.

## Installation
You can install `steem-python-dshot` with `pip`:

```
pip install -U steem-dshot
```

## Documentation
Documentation of the main package is available at **http://steem.readthedocs.io**
